---
name: Request for new material
about: Use this template for requesting new materials (.ncmat files).
title: 'Request for new material : <<MATERIALNAMEHERE>>'
labels: data library
assignees: ''

---

Please describe the material here, provide as much info as possible - crystal structure, phonon DOS curves, links to relevant online databases, .... Don't worry if you don't have much info, just try to descrive as much as you can. It is also helpful to hear why you need the material, for what project, etc. Of course, we can't guarantee that we will be able to create files for all materials requested in this manner, as some materials might be more difficult.
